@@ -90,8 +90,11 @@ class Fatura(models.Model):
     dados_endereco_cep = models.CharField(db_column="fatura_dados_endereco_cep")
     boleto_codigo_de_barras = models.CharField(db_column="fatura_boleto_codigo_de_barras", default=None)
     boleto_url = models.CharField(db_column="fatura_boleto_url", default=None)
-    cartao_de_credito_cv = models.CharField(db_column="fatura_cartao_de_credito_cv")
-    cartao_de_credito_numero = models.CharField(db_column="fatura_cartao_de_credito_numero")
+    cartao_de_credito_cv = models.CharField(db_column="fatura_cartao_de_credito_cv", default=None)
+    cartao_de_credito_numero = models.CharField(db_column="fatura_cartao_de_credito_numero", default=None)
+    cartao_de_credito_msgret = models.CharField(db_column="fatura_cartao_de_credito_msgret", default=None)
+    cartao_de_credito_codret = models.CharField(db_column="fatura_cartao_de_credito_codret", default=None)
+    cartao_de_credito_data_autorizacao = models.DateField(db_column="fatura_cartao_de_credito_data_autorizacao", default=None)
     controle_lancamento_numero = models.IntegerField(db_column="fatura_controle_lancamento_numero", default=None)
     controle_lancamento_quitado = models.BooleanField(db_column="fatura_controle_lancamento_quitado", default=False)
     controle_nota_fiscal = models.IntegerField(db_column="fatura_controle_nota_fiscal", default=None)
